@@ -18,19 +18,18 @@ class DashboardStatsCriteria(models.Model):
     **Name of DB table**: dash_stats_criteria
     """
     criteria_name = models.CharField(max_length=90, db_index=True,
-                    verbose_name=_('criteria name'),
-                    help_text=_("it needs to be one word unique. Ex. status, yesno"))
+        verbose_name=_('criteria name'),
+        help_text=_("it needs to be one word unique. Ex. status, yesno"))
     criteria_fix_mapping = jsonfield.fields.JSONField(null=True, blank=True,
-                           verbose_name=_("fixed criteria / value"),
-                           help_text=_(u'a JSON dictionary of key-value pairs that will be used for the criteria'))
+        verbose_name=_("fixed criteria / value"),
+        help_text=_("a JSON dictionary of key-value pairs that will be used for the criteria"))
     dynamic_criteria_field_name = models.CharField(max_length=90, blank=True, null=True,
-                                  verbose_name=_("dynamic criteria field name"),
-                                  help_text=_("ex. for call records - disposition"))
+        verbose_name=_("dynamic criteria field name"),
+        help_text=_("ex. for call records - disposition"))
     criteria_dynamic_mapping = jsonfield.fields.JSONField(null=True, blank=True,
-                               verbose_name=_("dynamic criteria / value"),
-                               help_text=_(u'a JSON dictionary of key-value pairs that will be used for the criteria'))
-    created_date = models.DateTimeField(auto_now_add=True,
-                                        verbose_name=_('date'))
+        verbose_name=_("dynamic criteria / value"),
+        help_text=_("a JSON dictionary of key-value pairs that will be used for the criteria"))
+    created_date = models.DateTimeField(auto_now_add=True, verbose_name=_('date'))
     updated_date = models.DateTimeField(auto_now=True)
 
     class Meta:
