@@ -9,12 +9,12 @@ from cache_utils.decorators import cached
 from admin_tools.dashboard import modules
 from admin_tools_stats.models import DashboardStats
 from datetime import datetime, timedelta
+import time
 
 # Make timezone aware for Django 1.4
 try:
     from django.utils.timezone import now
 except ImportError:
-    from datetime import datetime
     now = datetime.now
 
 
@@ -23,15 +23,21 @@ class DashboardChart(modules.DashboardModule):
 
     Default values are best suited for 2-column dashboard layouts.
     """
-    title = _('Dashboard Stats')
+    title = _('dashboard stats').title()
     template = 'admin_tools_stats/modules/chart.html'
-    chart_size = "380x100"
     days = None
     interval = 'days'
+    tooltip_date_format = "%d %b %Y"
+    chart_type = 'discreteBarChart'
+    chart_height = 300
+    chart_width = '100%'
+    require_chart_jscss = False
+    extra = dict()
 
     model = None
     graph_key = None
     filter_list = None
+    chart_container = None
 
     def is_empty(self):
         return False
@@ -40,6 +46,7 @@ class DashboardChart(modules.DashboardModule):
         super(DashboardChart, self).__init__(*args, **kwargs)
         self.select_box_value = ''
         for key in kwargs:
+            self.require_chart_jscss = kwargs['require_chart_jscss']
             self.graph_key = kwargs['graph_key']
             if kwargs.get('select_box_' + self.graph_key):
                 self.select_box_value = kwargs['select_box_' + self.graph_key]
@@ -50,25 +57,14 @@ class DashboardChart(modules.DashboardModule):
 
         self.data = self.get_registrations(self.interval, self.days,
                                            self.graph_key, self.select_box_value)
-        self.prepare_template_data(
-            self.data, self.graph_key, self.select_box_value)
-
-    def get_caption(self, dt):
-        """Displays caption on the x-axis of dashboard graph"""
-        return {
-            'hours': dt.strftime("%H"),
-            'days': dt.strftime("%a"),
-            'months': dt.strftime("%b"),
-            'weeks': dt.strftime('%W'),
-        }[self.interval]
+        self.prepare_template_data(self.data, self.graph_key, self.select_box_value)
 
     @cached(60 * 5)
     def get_registrations(self, interval, days, graph_key, select_box_value):
         """ Returns an array with new users count per interval."""
         try:
             conf_data = DashboardStats.objects.get(graph_key=graph_key)
-            model_name = get_model(
-                conf_data.model_app_name, conf_data.model_name)
+            model_name = get_model(conf_data.model_app_name, conf_data.model_name)
             kwargs = {}
 
             for i in conf_data.criteria.all():
@@ -105,8 +101,38 @@ class DashboardChart(modules.DashboardModule):
 
     def prepare_template_data(self, data, graph_key, select_box_value):
         """ Prepares data for template (passed as module attributes) """
-        self.captions = [self.get_caption(t[0]) for t in data]
-        self.values = [t[1] for t in data]
+        self.extra = {
+            'x_is_date': True,
+            'tag_script_js': False,
+            'jquery_on_ready': False,
+        }
+        if self.interval == 'months':
+            self.tooltip_date_format = "%b"
+            self.extra['x_axis_format'] = "%b"
+        if self.interval == 'days':
+            self.tooltip_date_format = "%d %b %Y"
+            self.extra['x_axis_format'] = "%a"
+        if self.interval == 'hours':
+            self.tooltip_date_format = "%d %b %Y %H:%S"
+            self.extra['x_axis_format'] = "%H"
+
+        self.chart_container = self.interval + '_' + self.graph_key
+
+        xdata = []
+        ydata = []
+        for data_date in self.data:
+            start_time = int(time.mktime(data_date[0].timetuple()) * 1000)
+            xdata.append(start_time)
+            ydata.append(data_date[1])
+
+        extra_serie = {"tooltip": {"y_start": "", "y_end": ""},
+                       "date_format": self.tooltip_date_format}
+
+        self.values = {
+            'x': xdata,
+            'name1': self.interval, 'y1': ydata, 'extra1': extra_serie,
+        }
+
         self.max_value = max(self.values)
         self.form_field = get_dynamic_criteria(graph_key, select_box_value)
 
@@ -114,8 +140,7 @@ class DashboardChart(modules.DashboardModule):
 def get_title(graph_key):
     """Returns graph title"""
     try:
-        conf_data = DashboardStats.objects.get(graph_key=graph_key)
-        return conf_data.graph_title
+        return DashboardStats.objects.get(graph_key=graph_key).graph_title
     except:
         return ''
 
@@ -124,19 +149,17 @@ def get_dynamic_criteria(graph_key, select_box_value):
     """To get dynamic criteria & return into select box to display on dashboard"""
     try:
         temp = ''
-        conf_data = DashboardStats.objects.get(graph_key=graph_key)
-        for i in conf_data.criteria.all():
+        conf_data = DashboardStats.objects.get(graph_key=graph_key).criteria.all()
+        for i in conf_data:
             dy_map = i.criteria_dynamic_mapping
             if dy_map:
-                temp = '<select name="select_box_' + graph_key + '" onChange="this.form.submit();">'
+                temp = '<select name="select_box_' + graph_key + '" onChange="$(\'#stateform\').submit();">'
                 for key in dict(dy_map):
                     value = dy_map[key]
                     if key == select_box_value:
-                        temp += '<option value="' + \
-                            key + '" selected=selected>' + value + '</option>'
+                        temp += '<option value="' + key + '" selected=selected>' + value + '</option>'
                     else:
-                        temp += '<option value="' + \
-                            key + '">' + value + '</option>'
+                        temp += '<option value="' + key + '">' + value + '</option>'
                 temp += '</select>'
 
         return mark_safe(force_unicode(temp))
@@ -146,36 +169,28 @@ def get_dynamic_criteria(graph_key, select_box_value):
 
 def get_active_graph():
     """Returns active graphs"""
-    graph_list = []
     try:
-        graph_list = DashboardStats.objects.filter(is_visible=1)
-        return graph_list
+        return DashboardStats.objects.filter(is_visible=1)
     except:
-        return graph_list
+        return []
 
 
 def get_registration_charts(**kwargs):
     """ Returns 3 basic chart modules (today, last 7 days & last 3 months) """
-    for key in kwargs:
-        #value = kwargs[key]
-        key_value = kwargs['graph_key']
     return [
-        DashboardChart(_('today').title(), interval='hours', **kwargs),
-        DashboardChart(_('last week').title(), interval='days', **kwargs),
+        DashboardChart(('today').title(), interval='hours', **kwargs),
+        DashboardChart(('last week').title(), interval='days', **kwargs),
         #DashboardChart(_('Last 2 Weeks'), interval='weeks', **kwargs),
-        DashboardChart(_('last months').title(), interval='months', **kwargs),
+        DashboardChart(('last months').title(), interval='months', **kwargs),
     ]
 
 
 class DashboardCharts(modules.Group):
     """Group module with 3 default dashboard charts"""
-    #title = _('New Users')
-    key_value = ''
+    title = _('new users')
 
     def __init__(self, *args, **kwargs):
-        for key in kwargs:
-            #value = kwargs[key]
-            key_value = kwargs['graph_key']
+        key_value = kwargs.get('graph_key')
+        self.title = get_title(key_value)
         kwargs.setdefault('children', get_registration_charts(**kwargs))
         super(DashboardCharts, self).__init__(*args, **kwargs)
-        self.title = get_title(key_value)
